package prefuse.data.column;

import java.util.Comparator;
import java.util.Map;
import prefuse.data.Table;
import prefuse.data.event.ColumnListener;
import prefuse.data.util.Index;
import prefuse.util.TypeLib;
import prefuse.util.collections.DefaultLiteralComparator;

public class ColumnMetadata
  implements ColumnListener
{
  private Table m_table;
  private String m_column;
  private boolean m_dynamic;
  private boolean m_init;
  private Comparator m_cmp;
  private Object m_default;
  private int m_min;
  private int m_max;
  private int m_median;
  private int m_unique;
  private Double m_mean;
  private Double m_stdev;
  private Double m_sum;
  private Object[] m_ordinalA;
  private Map m_ordinalM;
  
  public ColumnMetadata(Table paramTable, String paramString)
  {
    this(paramTable, paramString, DefaultLiteralComparator.getInstance(), true);
  }
  
  public ColumnMetadata(Table paramTable, String paramString, Comparator paramComparator, boolean paramBoolean)
  {
    this.m_table = paramTable;
    this.m_column = paramString;
    this.m_cmp = paramComparator;
    this.m_dynamic = paramBoolean;
  }
  
  public void dispose()
  {
    this.m_table.getColumn(this.m_column).removeColumnListener(this);
  }
  
  private void clearCachedValues()
  {
    this.m_min = -1;
    this.m_max = -1;
    this.m_median = -1;
    this.m_unique = -1;
    this.m_mean = null;
    this.m_stdev = null;
    this.m_sum = null;
    this.m_ordinalA = null;
    this.m_ordinalM = null;
  }
  
  public void calculateValues()
  {
    clearCachedValues();
    boolean bool = this.m_dynamic;
    this.m_dynamic = true;
    getMinimumRow();
    getMaximumRow();
    getMedianRow();
    getUniqueCount();
    if (TypeLib.isNumericType(this.m_table.getColumnType(this.m_column)))
    {
      getMean();
      getDeviation();
      getSum();
    }
    getOrdinalArray();
    getOrdinalMap();
    this.m_init = true;
    this.m_dynamic = bool;
  }
  
  private void accessCheck()
  {
    if (this.m_init) {
      return;
    }
    if (this.m_dynamic)
    {
      clearCachedValues();
      this.m_table.getColumn(this.m_column).addColumnListener(this);
    }
    else
    {
      calculateValues();
    }
    this.m_init = true;
  }
  
  public Comparator getComparator()
  {
    return this.m_cmp;
  }
  
  public void setComparator(Comparator paramComparator)
  {
    this.m_cmp = paramComparator;
    clearCachedValues();
  }
  
  public Object getDefaultValue()
  {
    return this.m_default;
  }
  
  public int getMinimumRow()
  {
    accessCheck();
    if ((this.m_min == -1) && (this.m_dynamic))
    {
      Index localIndex = this.m_table.getIndex(this.m_column);
      if (localIndex != null) {
        this.m_min = localIndex.minimum();
      } else {
        this.m_min = Columns.min(this.m_table, this.m_column, this.m_cmp);
      }
    }
    return this.m_min;
  }
  
  public int getMaximumRow()
  {
    accessCheck();
    if ((this.m_max == -1) && (this.m_dynamic))
    {
      Index localIndex = this.m_table.getIndex(this.m_column);
      if (localIndex != null) {
        this.m_max = localIndex.maximum();
      } else {
        this.m_max = Columns.max(this.m_table, this.m_column, this.m_cmp);
      }
    }
    return this.m_max;
  }
  
  public int getMedianRow()
  {
    accessCheck();
    if ((this.m_median == -1) && (this.m_dynamic))
    {
      Index localIndex = this.m_table.getIndex(this.m_column);
      if (localIndex != null) {
        this.m_max = localIndex.median();
      } else {
        this.m_median = Columns.median(this.m_table, this.m_column, this.m_cmp);
      }
    }
    return this.m_median;
  }
  
  public int getUniqueCount()
  {
    accessCheck();
    if ((this.m_unique == -1) && (this.m_dynamic))
    {
      Index localIndex = this.m_table.getIndex(this.m_column);
      if (localIndex != null) {
        this.m_unique = localIndex.uniqueCount();
      } else {
        this.m_unique = Columns.uniqueCount(this.m_table, this.m_column);
      }
    }
    return this.m_unique;
  }
  
  public double getMean()
  {
    accessCheck();
    if ((this.m_mean == null) && (this.m_dynamic)) {
      this.m_mean = new Double(Columns.mean(this.m_table, this.m_column));
    }
    return this.m_mean.doubleValue();
  }
  
  public double getDeviation()
  {
    accessCheck();
    if ((this.m_stdev == null) && (this.m_dynamic)) {
      this.m_stdev = new Double(Columns.deviation(this.m_table, this.m_column, getMean()));
    }
    return this.m_stdev.doubleValue();
  }
  
  public double getSum()
  {
    accessCheck();
    if ((this.m_sum == null) && (this.m_dynamic)) {
      this.m_sum = new Double(Columns.sum(this.m_table, this.m_column));
    }
    return this.m_sum.doubleValue();
  }
  
  public Object[] getOrdinalArray()
  {
    accessCheck();
    if ((this.m_ordinalA == null) && (this.m_dynamic)) {
      this.m_ordinalA = Columns.ordinalArray(this.m_table, this.m_column, this.m_cmp);
    }
    return this.m_ordinalA;
  }
  
  public Map getOrdinalMap()
  {
    accessCheck();
    if ((this.m_ordinalM == null) && (this.m_dynamic)) {
      this.m_ordinalM = Columns.ordinalMap(this.m_table, this.m_column, this.m_cmp);
    }
    return this.m_ordinalM;
  }
  
  public void columnChanged(Column paramColumn, int paramInt1, int paramInt2, int paramInt3)
  {
    clearCachedValues();
  }
  
  public void columnChanged(Column paramColumn, int paramInt, boolean paramBoolean)
  {
    columnChanged(paramColumn, 0, paramInt, paramInt);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, double paramDouble)
  {
    columnChanged(paramColumn, 0, paramInt, paramInt);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, float paramFloat)
  {
    columnChanged(paramColumn, 0, paramInt, paramInt);
  }
  
  public void columnChanged(Column paramColumn, int paramInt1, int paramInt2)
  {
    columnChanged(paramColumn, 0, paramInt1, paramInt1);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, long paramLong)
  {
    columnChanged(paramColumn, 0, paramInt, paramInt);
  }
  
  public void columnChanged(Column paramColumn, int paramInt, Object paramObject)
  {
    columnChanged(paramColumn, 0, paramInt, paramInt);
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\data\column\ColumnMetadata.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */